package
Version:
v0.0.0-...-4e030f6
Opens a new window with list of versions in this module.
Published: Dec 28, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type InnerTitle struct {
Text struct {
Content string `json:"content,omitempty"`
} `json:"text,omitempty"`
}
type Title struct {
Title []InnerTitle `json:"title,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.